/*
side-matter-admin.js
Version 1.0

Plugin: Side Matter
Author: Christopher Setzer
URI: http://wordpress.org/extend/plugins/side-matter/
License: GPLv2
*/

(function($) {

/* Variables */

var fieldIsDark; // True when `div.side-matter-field` has class `side-matter-field-dark` applied
var colorsEnabled; // True when 'Use custom colors for figures and notes' checkbox is checked
var figureColor; // Current color to use for reference and note numeral figures
var textColor; // Current color to use for note text

var figures = { // Numeral style figures for preview field
	'armenian': 'Ա',
	'decimal': '1',
	'georgian': 'ა',
	'hebrew': 'א',
	'lower-alpha': 'a',
	'lower-greek': 'α',
	'lower-roman': 'i',
	'none': ''
};

$(document).ready(function() { // Assign initial values, position note in preview field, and load color pickers

	fieldIsDark = 0;
	figureColor = $('.figure_color').val();
	textColor = $('.text_color').val();

	placeNote();

	$('.figure_color').wpColorPicker(figureOptions);
	$('.text_color').wpColorPicker(textOptions);

	if ( ! $('#colors_enabled').prop('checked')) {
		$('.user_colors').hide();
	} else {
		$('.side-matter-ref,.side-matter-note').css('color', figureColor);
		$('.side-matter-text').css('color', textColor);
	}

});

function placeNote() { // Position note in preview field (variant of `placeNotes` from `side-matter.js`)
	var refPosition = $('.side-matter-ref').position().top;
	var notePosition = $('.side-matter-note').position().top;
	var noteOffset = refPosition - notePosition;
	var finalOffset = (noteOffset < 0) ? 0 : noteOffset;
	$('.side-matter-note').css('marginTop', finalOffset); // Position note
}

/* Parameters for updating preview field text colors when color picker is changed */

var figureOptions = {
	change: function(event, ui) {
    	$('.side-matter-ref,.side-matter-note').css('color', ui.color.toString());
    }
};

var textOptions = {
	change: function(event, ui) {
    	$('.side-matter-text').css('color', ui.color.toString());
    }
};

/* Functions for live updates to preview field: toggling light/dark, enabling custom colors, updating figure style */

$('.side-matter-field,label[for^="preview_field"]').click(function() { // When user clicks preview field or its label, toggle class
	if (fieldIsDark == 0) {
		$('.side-matter-field').addClass('side-matter-field-dark');
		fieldIsDark = 1;
	} else {
		$('.side-matter-field').removeClass('side-matter-field-dark');
		fieldIsDark = 0;
	}
});

$('.side-matter-field').keyup(function(e) { // Enter and space keys will toggle preview field when it is in focus
	if (e.which == 13 || e.which == 32) $('.side-matter-field').click();
});

$('#colors_enabled').click(function() { // When user clicks 
	if ($(this).prop('checked')) {
		$('.side-matter-ref,.side-matter-note').css('color', figureColor);
		$('.side-matter-text').css('color', textColor);
		$('.user_colors').slideDown();
	} else {
		figureColor = $('.figure_color').val();
		textColor  = $('.text_color').val();
		$('.user_colors').slideUp('fast');
		$('.side-matter-ref,.side-matter-note,.side-matter-text').css('color', '');
	}
});

$('#figure_style').change(function() {
	$('.side-matter-ref').text(figures[$(this).val()]);
	$('.side-matter-note').css('listStyleType', $(this).val());
});

})(jQuery);
